@@ -20,10 +20,9 @@ class AppEnvironmentSerializer(NetBoxModelSerializer):
 class OCPProjectSerializer(NetBoxModelSerializer):
     url = HyperlinkedIdentityField(view_name="plugins-api:ocp_project_plugin-api:ocpproject-detail")
     customer = NestedTenantSerializer()
-    contact = NestedContactSerializer()
-    owner = NestedContactSerializer()
+    project_owner = NestedContactSerializer()
 
     class Meta:
         model = OCPProject
-        fields = ["url", "id", "name", "description", "display_name", "owner", "contact", "customer", "docu_url",
+        fields = ["url", "id", "name", "description", "display_name", "project_owner", "customer", "docu_url",
                   "workload", "request", "created", "last_updated", "custom_fields"]
