@@ -8,7 +8,7 @@ from ocp_project_plugin.models import OCPProject
 class OCPProjectFilter(NetBoxModelFilterSet):
     class Meta:
         model = OCPProject
-        fields = ['name', 'description', 'display_name', 'owner', 'contact', 'customer', 'docu_url', 'workload',
+        fields = ['name', 'description', 'display_name', 'project_owner', 'customer', 'docu_url', 'workload',
                   'request']
 
     def search(self, queryset, name, value):
