@@ -1,3 +1,4 @@
+from django.db.models import ForeignKey, PROTECT
 from django.forms import (
     CharField,
 )
@@ -10,7 +11,7 @@ from netbox.forms import (
 )
 from ocp_project_plugin.models import OCPProject
 from tenancy.models import Tenant, Contact
-from utilities.forms import DynamicModelChoiceField
+from utilities.forms import DynamicModelChoiceField, CSVModelChoiceField
 
 
 class OCPProjectForm(NetBoxModelForm):
@@ -45,6 +46,8 @@ class OCPProjectFilterForm(NetBoxModelFilterSetForm):
 
     name = CharField(
         required=False,
+        label='OCP Project Name',
+        help_text='The ocp project name e.g. web-shop',
     )
     description = CharField(
         required=False,
@@ -56,15 +59,17 @@ class OCPProjectFilterForm(NetBoxModelFilterSetForm):
         label='Display name',
         help_text='Display Name of the project e.g. Web Shop Shopify'
     )
-    project_owner = CharField(
+    project_owner = DynamicModelChoiceField(
         required=False,
+        queryset=Contact.objects.all(),
         label='Project Owner',
-        help_text='Choose the tenant'
+        help_text='Choose the Project Owner'
     )
-    customer = CharField(
+    customer = DynamicModelChoiceField(
         required=False,
+        queryset=Tenant.objects.all(),
         label='Customer name',
-        help_text='Choose the tenant'
+        help_text='Choose the tenant',
     )
     docu_url = CharField(
         required=False,
@@ -100,9 +105,11 @@ class OCPProjectImportForm(NetBoxModelImportForm):
         label='Project Owner',
         help_text='Choose the tenant'
     )
-    customer = CharField(
-        label='Customer name',
-        help_text='Choose the tenant'
+    customer = CSVModelChoiceField(
+        queryset=Tenant.objects.all(),
+        to_field_name='name',
+        required=False,
+        related_name='ocp_project_tenant',
     )
     docu_url = CharField(
         label='URL',
