@@ -21,9 +21,12 @@ STORAGE_COST = PLUGIN_SETTINGS.get('storage_cost', '')
 memory_validator = RegexValidator(r"[1-9][0-9]*(Mi|Gi)$", "The input should contain only positive Number, which ends "
                                                           "with Mi (Megabyte) or Gi (Gigabyte)")
 
-project_name_validator = RegexValidator(r"^([a-z]|[-]){1,30}$", "The input should contain only small letters,"
-                                                                     " Numbers or - sign, it also should no exceed 30 "
-                                                                     "Characters")
+project_name_validator = RegexValidator(r"^([a-z]|[-]|[0-9]){1,30}$", "The input should contain only small letters,"
+                                                                      " Numbers or - sign, it also should no exceed 30 "
+                                                                      "Characters")
+
+url_validator = RegexValidator(r"https?:\/\/(www\.)?[-a-zA-Z0-9@:%._\+~#=]{1,256}\.[a-zA-Z0-9()]{1,6}\b([-a-zA-Z0-9()@:%_\+.~#?&//=]*)",
+                               "The url validation failed")
 
 
 class OCPProject(NetBoxModel):
@@ -34,12 +37,12 @@ class OCPProject(NetBoxModel):
         validators=[project_name_validator],
     )
     description = CharField(
-        max_length=255,
+        max_length=150,
         verbose_name="Description",
         help_text="The description of the project e.g. A web shop software",
     )
     display_name = CharField(
-        max_length=255,
+        max_length=50,
         verbose_name="Display name",
         help_text="Display Name of the project e.g. Web Shop Shopify"
     )
@@ -57,6 +60,7 @@ class OCPProject(NetBoxModel):
         max_length=255,
         verbose_name="URL",
         help_text="The url of the project documentation e.g. https://confluence.com/space/project",
+        validators=[url_validator],
     )
     workload = CharField(
         max_length=255,
